/vpcs/{uuid} — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »

# /vpcs/{uuid}

Contents

- /vpcs/{uuid}
  - GET /vpcs/{uuid}
    - Parameters
    - Response status codes
    - Output
    - Sample session
  - PUT /vpcs/{uuid}
    - Parameters
    - Response status codes
    - Input
    - Output
  - DELETE /vpcs/{uuid}
    - Parameters
    - Response status codes

## GET /vpcs/{uuid}

Get a VPCS instance

### Parameters

- uuid: Instance UUID

### Response status codes

- 200: Success
- 404: Instance doesn’t exist

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
console | ✔ | integer | console TCP port
name | ✔ | string | VPCS device name
project_id | ✔ | string | Project UUID
script_file |  | ['string', 'null'] | VPCS startup script
startup_script |  | ['string', 'null'] | Content of the VPCS startup script
uuid | ✔ | string | VPCS device UUID

### Sample session

    curl -i -X GET 'http://localhost:8000/vpcs/{uuid}'

    GET /vpcs/{uuid} HTTP/1.1

    HTTP/1.1 200
    CONNECTION: keep-alive
    CONTENT-LENGTH: 211
    CONTENT-TYPE: application/json
    DATE: Thu, 08 Jan 2015 16:09:15 GMT
    SERVER: Python/3.4 GNS3/1.3.dev1
    X-ROUTE: /v1/vpcs/{uuid}

    {
        "console": 2003,
        "name": "PC TEST 1",
        "project_id": "a1e920ca-338a-4e9f-b363-aa607b09dd80",
        "script_file": null,
        "startup_script": null,
        "uuid": "6d2d8dd3-4b2f-43cb-a95d-301f5c65606b"
    }

## PUT /vpcs/{uuid}

Update a VPCS instance

### Parameters

- uuid: Instance UUID

### Response status codes

- 200: Instance updated
- 409: Conflict
- 404: Instance doesn’t exist

### Input

Name | Mandatory | Type | Description
--- | --- | --- | ---
console |  | ['integer', 'null'] | console TCP port
name |  | ['string', 'null'] | VPCS device name
startup_script |  | ['string', 'null'] | Content of the VPCS startup script

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
console | ✔ | integer | console TCP port
name | ✔ | string | VPCS device name
project_id | ✔ | string | Project UUID
script_file |  | ['string', 'null'] | VPCS startup script
startup_script |  | ['string', 'null'] | Content of the VPCS startup script
uuid | ✔ | string | VPCS device UUID

## DELETE /vpcs/{uuid}

Delete a VPCS instance

### Parameters

- uuid: Instance UUID

### Response status codes

- 404: Instance doesn’t exist
- 204: Instance deleted

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »